Partitioning
============

.. currentmodule:: npap.partitioning

Partitioning strategies for network clustering.

Geographical Partitioning
-------------------------

.. automodule:: npap.partitioning.geographical
   :members:
   :show-inheritance:
   :no-index:

Electrical Distance Partitioning
--------------------------------

.. automodule:: npap.partitioning.electrical
   :members:
   :show-inheritance:
   :no-index:

Voltage-Aware Partitioning
--------------------------

.. automodule:: npap.partitioning.va_geographical
   :members:
   :show-inheritance:
   :no-index:

.. automodule:: npap.partitioning.va_electrical
   :members:
   :show-inheritance:
   :no-index:
